/*
 * exthooks.h: Additional hooks for 3rd party plugins
 *
 * Licensed under GPL2
 */
#ifndef __EXTHOOKS_H
#define __EXTHOOKS_H

#include <linux/dvb/ca.h>
#include "channels.h"
#include "ci.h"
#include "device.h"

class cExtHookGroupOne;
class cExtHookGroupTwo;

#define VDR_HAS_EXTHOOKS 100

class cExtHooks
{
private:
	static bool pastTimers;

	static cExtHookGroupOne oneDefault;
	static cExtHookGroupOne *oneCustom;
	static bool oneReady;

	static cExtHookGroupTwo twoDefault;
	static cExtHookGroupTwo *twoCustom;
	static bool twoReady;
	
public:
	static bool PastTimers() { return pastTimers; }
	static void SetPastTimers(bool PastTimers) { pastTimers = PastTimers; }

	static cExtHookGroupOne *One();
	static cExtHookGroupTwo *Two();
	
	static bool RegisterGroupOne(cExtHookGroupOne *hooks);
	static bool RegisterGroupTwo(cExtHookGroupTwo *hooks);
	static void UnregisterGroupOne();
	static void UnregisterGroupTwo();

};


#define VDR_HAS_HOOKGROUPONE 330

class cExtHookGroupOne
{
public:
	virtual bool TryAnyway(const cDevice *dev, int *NumCams) { return false; }
	virtual bool NociHandler(const cDevice *dev, unsigned short *ids) { return false; }
	virtual void SetPid(const cDevice *dev, int pid, int type) { return; }
	virtual void DelPid(const cDevice *dev, int pid) { return; }
	virtual bool JumpToResultTrue(const cDevice *dev, const cChannel *channel) { return false; }
	virtual bool TurnOffLivePIDs(const cDevice *dev, const cChannel *channel) { return false; }
	virtual void Tuning(const cDevice *dev, const cChannel *channel) { return; }
	virtual bool OverrideCaids(unsigned short CaSystemIds) { return false; }
};

#define VDR_HAS_HOOKGROUPTWO 100

class cExtHookGroupTwo
{
public:
	virtual void SetCaDescr(void **privdata, cMutex *mutex, ca_descr_t *ca_descr) { return; }
	virtual void SetCaPid(void **privdata, cMutex *mutex, ca_pid_t *ca_pid) { return; }
	virtual cDevice *FindDeviceIfNeeded(int CardIndex) { return NULL; }
	virtual bool PossiblyDecrypt(void **privdata, cMutex *mutex, unsigned char *p, int Count, unsigned char **lastP, int *lastCount) { return false; }
	virtual void DeletePrivdata(void *privdata) { return; }
};

#endif

